@@ -725,8 +725,9 @@ static gpointer ClientThread(gpointer ptr)
 
     g_message("client thread starting... fd = %d", fd);
 
-    if (fileFd == -1 && gst_element_set_state(pipeline, GST_STATE_PLAYING) ==
-        GST_STATE_CHANGE_FAILURE)
+    if (fileFd == -1 &&
+        (pipeline == NULL || gst_element_set_state(pipeline, GST_STATE_PLAYING) ==
+         GST_STATE_CHANGE_FAILURE))
     {
         g_error("Error when trying to set pipeline playing");
     }
@@ -804,7 +805,7 @@ static gpointer ServerThread(gpointer ptr)
 
     struct sockaddr_in sa;
     struct sockaddr_in saClient;
-    socklen_t clientNameLen;
+    socklen_t addrLen;
     gint clientSocketFd;
     gint optval;
 
@@ -836,9 +837,10 @@ static gpointer ServerThread(gpointer ptr)
     }
     while (1)
     {
+        addrLen = sizeof(struct sockaddr_in);
         clientSocketFd = accept(socketFd,
                                 (struct sockaddr *)&saClient,
-                                &clientNameLen);
+                                &addrLen);
         if (clientSocketFd < 0)
         {
             g_warning("accept failed: %s", strerror(errno));
@@ -987,6 +989,14 @@ static gboolean Start(const gboolean enableMotionDet)
         g_message("Motion detection disabled");
     }
 
+    CreatePipeline(cmdLineParams->size,
+                   cmdLineParams->fps,
+                   cmdLineParams->quality,
+                   scalefactor,
+                   fileFd != -1 ? TRUE : FALSE);
+
+    g_message("Pipeline created");
+
     if (g_thread_create(&ServerThread, NULL, FALSE, NULL) == NULL)
     {
         g_error("Could not start server thread");
@@ -1012,13 +1022,6 @@ static gboolean Start(const gboolean enableMotionDet)
         g_message("File thread spawned");
     }
 
-    CreatePipeline(cmdLineParams->size,
-                   cmdLineParams->fps,
-                   cmdLineParams->quality,
-                   scalefactor,
-                   fileFd != -1 ? TRUE : FALSE);
-
-    g_message("Pipeline created");
 
     return (TRUE);
 
@@ -1202,6 +1205,8 @@ int main(int argc, char *argv[])
 
     g_message("starting up...");
 
+    g_thread_init(NULL);
+
     /* this makes GStreamer to find our plugins, for some reason giving
      * --gst-plugin-path=/usr/lib/gstmjpg from the command line did not work */
     setenv("GST_PLUGIN_PATH", "/usr/lib/gstmjpg", 1);
